pub struct BybitMarginRepayResult {
pub coin: String,
pub amount: Option<String>,
pub success: bool,
pub result_status: String,
pub message: String,
pub ts_event: u64,
pub ts_init: u64,
}Expand description
Result from a Bybit repay operation for strategy consumption.
Fields
coin: StringThe coin that was repaid.
amount: Option<String>The amount that was repaid (None if repaying all).
success: boolWhether the repay operation was successful.
result_status: StringThe result status from Bybit API.
message: StringError message if the operation failed.
ts_event: u64UNIX timestamp (nanoseconds) when the event occurred.
ts_init: u64UNIX timestamp (nanoseconds) when the object was initialized.
Implementations
Sourceimpl BybitMarginRepayResult
impl BybitMarginRepayResult
Sourcepub fn py_new(
coin: String,
amount: Option<String>,
success: bool,
result_status: String,
message: String,
ts_event: u64,
ts_init: u64,
) -> Self
pub fn py_new( coin: String, amount: Option<String>, success: bool, result_status: String, message: String, ts_event: u64, ts_init: u64, ) -> Self
Result from a Bybit repay operation for strategy consumption.
pub fn coin(&self) -> &str
pub fn amount(&self) -> Option<&str>
pub fn success(&self) -> bool
pub fn result_status(&self) -> &str
pub fn message(&self) -> &str
pub fn ts_event(&self) -> u64
pub fn ts_init(&self) -> u64